@@ -26,6 +26,7 @@ import java.nio.ByteBuffer;
 import java.nio.charset.Charset;
 import java.util.BitSet;
 import java.util.Locale;
+import java.util.regex.Pattern;
 
 import org.apache.james.mime4j.Charsets;
 import org.apache.james.mime4j.util.CharsetUtil;
@@ -55,6 +56,8 @@ public class EncoderUtil {
 
     private static final BitSet ATEXT_CHARS = initChars("()<>@.,;:\\\"[]");
 
+    private static final Pattern QUOTE = Pattern.compile("[\\\\\"]");
+
     private static BitSet initChars(String specials) {
         BitSet bs = new BitSet(128);
         for (char ch = 33; ch < 127; ch++) {
@@ -175,7 +178,7 @@ public class EncoderUtil {
      *            whether the encoded-word is to be used to replace a text token
      *            or a word entity (see RFC 822).
      * @param usedCharacters
-     *            number of characters already used up (<code>0 <= usedCharacters <= 50</code>).
+     *            number of characters already used up (<code>0 &lt;= usedCharacters &lt;= 50</code>).
      * @return the specified text if encoding is not necessary or an encoded
      *         word or a sequence of encoded words otherwise.
      */
@@ -197,7 +200,7 @@ public class EncoderUtil {
      * @param text
      *            text to analyze.
      * @param usedCharacters
-     *            number of characters already used up (<code>0 <= usedCharacters <= 50</code>).
+     *            number of characters already used up (<code>0 &lt;= usedCharacters &lt;= 50</code>).
      * @return <code>true</code> if the specified text has to be encoded into
      *         an encoded-word, <code>false</code> otherwise.
      */
@@ -271,7 +274,7 @@ public class EncoderUtil {
      *            whether the encoded-word is to be used to replace a text token
      *            or a word entity (see RFC 822).
      * @param usedCharacters
-     *            number of characters already used up (<code>0 <= usedCharacters <= 50</code>).
+     *            number of characters already used up (<code>0 &lt;= usedCharacters &lt;= 50</code>).
      * @return the encoded word (or sequence of encoded words if the given text
      *         does not fit in a single encoded word).
      * @see #hasToBeEncoded(String, int)
@@ -292,7 +295,7 @@ public class EncoderUtil {
      *            whether the encoded-word is to be used to replace a text token
      *            or a word entity (see RFC 822).
      * @param usedCharacters
-     *            number of characters already used up (<code>0 <= usedCharacters <= 50</code>).
+     *            number of characters already used up (<code>0 &lt;= usedCharacters &lt;= 50</code>).
      * @param charset
      *            the Java charset that should be used to encode the specified
      *            string into a byte array. A suitable charset is detected
@@ -526,8 +529,7 @@ public class EncoderUtil {
         // VCHAR = %x21-7E
         // DQUOTE = %x22
 
-        String escaped = str.replaceAll("[\\\\\"]", "\\\\$0");
-        return "\"" + escaped + "\"";
+        return '"' + QUOTE.matcher(str).replaceAll("\\\\$0") + '"';
     }
 
     private static String encodeB(String prefix, String text,
@@ -566,12 +568,13 @@ public class EncoderUtil {
         if (totalLength <= ENCODED_WORD_MAX_LENGTH - usedCharacters) {
             return prefix + encodeQ(bytes, usage) + ENC_WORD_SUFFIX;
         } else {
-            String part1 = text.substring(0, text.length() / 2);
+            int splitOffset = text.offsetByCodePoints(text.length() / 2, -1);
+            String part1 = text.substring(0, splitOffset);
             byte[] bytes1 = encode(part1, charset);
             String word1 = encodeQ(prefix, part1, usage, usedCharacters,
                     charset, bytes1);
 
-            String part2 = text.substring(text.length() / 2);
+            String part2 = text.substring(splitOffset);
             byte[] bytes2 = encode(part2, charset);
             String word2 = encodeQ(prefix, part2, usage, 0, charset, bytes2);
 
