@@ -245,14 +245,14 @@ public class MimeBoundaryInputStream extends LineReaderInputStream {
                     // Make sure the boundary is terminated with EOS
                     break;
                 } else {
-                    // or with a whitespace or '--' 
+                    // or with a whitespace or '--'
                     char ch = (char)(buffer.byteAt(pos));
                     if (CharsetUtil.isWhitespace(ch)) {
                         break;
                     }
                     if (ch == '-' && remaining > 1 && (char)(buffer.byteAt(pos+1)) == '-') {
                         break;
-                    } 
+                    }
                 }
             }
             off = i + boundary.length;
@@ -265,8 +265,14 @@ public class MimeBoundaryInputStream extends LineReaderInputStream {
             if (eof) {
                 limit = buffer.limit();
             } else {
-                limit = buffer.limit() - (boundary.length + 2);
-                                // [LF] [boundary] [CR][LF] minus one char
+                int position = buffer.limit() - (boundary.length + 3);    // 2nd position before boundary
+                if (position >= 0 && (char) buffer.byteAt(position) == '\r') {
+                    limit = buffer.limit() - (boundary.length + 3);
+                    // boundary [CR][LF] minus two chars
+                } else {
+                    limit = buffer.limit() - (boundary.length + 2);
+                    // boundary [LF] minus one char
+                }
             }
         }
         return bytesRead;
