@@ -21,6 +21,10 @@ package org.apache.james.mime4j.dom.field;
 
 public interface ContentLengthField extends ParsedField {
 
+    default boolean bodyDescriptionField() {
+        return true;
+    }
+
     /**
      * Gets the content length value defined in this field.
      *
