@@ -21,6 +21,7 @@ package org.apache.james.mime4j.field;
 
 import java.io.IOException;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.Map;
@@ -100,7 +101,6 @@ public class FieldsTest {
         ContentTypeField field = Fields.contentType("multipart/mixed; "
                 + "boundary=-=Part.0.37877968dd4f6595.11eccf0271c"
                 + ".2dce5678cbc933d5=-");
-        Assert.assertFalse(field.isValidField());
 
         Assert.assertEquals("multipart/mixed", field.getMimeType());
     }
@@ -251,8 +251,8 @@ public class FieldsTest {
                 seventyEight)));
 
         String seventyNine = seventyEight + "9";
-        String expected = "Subject: =?US-ASCII?Q?1234567890123456789012345678901234?="
-                + "\r\n =?US-ASCII?Q?56789012345678901234567890123456789?=";
+        String expected = "Subject: =?US-ASCII?Q?123456789012345678901234567890123?="
+                + "\r\n =?US-ASCII?Q?456789012345678901234567890123456789?=";
         Assert.assertEquals(expected, decode(Fields.subject(seventyNine)));
     }
 
@@ -400,6 +400,14 @@ public class FieldsTest {
                 decode(field));
     }
 
+    @Test
+    public void testAddressListWhenMailboxAbsentDomain() {
+        Mailbox mailbox = new Mailbox("name1", "localpart", "");
+        AddressListField field = Fields.addressList("To", Collections.singleton(mailbox));
+        Assert.assertEquals(1, field.getAddressList().size());
+        Assert.assertEquals(mailbox, field.getAddressList().get(0));
+    }
+
     @Test
     public void testInvalidFieldName() throws Exception {
         try {
